==> mass_replace-0.0.2.tar.gz: mass_replace-0.0.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pip install twine

import os
import sys
import pathlib
from shutil import rmtree

from setuptools import find_packages, setup, Command

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# Package meta-data.
NAME = "mass_replace"
DESCRIPTION = "Walkthrough directories and find and replace txt on select filetypes."
URL = "https://github.com/Kilo59/mass_replace"
EMAIL = "gabriel59kg@gmail.com"
AUTHOR = "Gabriel Gore"
REQUIRES_PYTHON = ">=3.5.0"
# replace with __version__
VERSION = "0.0.2"

# What packages are required for this module to be executed?
REQUIRED = ["pyaml"]

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# The text of the README file
README = (HERE / "README.md").read_text(encoding="utf-8")

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    with open(os.path.join(here, NAME, "__version__.py")) as f:
        exec(f.read(), about)
else:
    about["__version__"] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = "Build and publish the package."
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print("\033[1m{0}\033[0m".format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status("Removing previous builds…")
            rmtree(os.path.join(here, "dist"))
        except OSError:
            pass

        self.status("Building Source and Wheel (universal) distribution…")
        os.system("{0} setup.py sdist bdist_wheel --universal".format(sys.executable))

        self.status("Uploading the package to PyPi via Twine…")
        os.system("twine upload dist/*")

        self.status("Pushing git tags…")
        os.system("git tag v{0}".format(about["__version__"]))
        os.system("git push --tags")

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about["__version__"],
    description=DESCRIPTION,
    long_description=README,
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(exclude=("tests",)),
    entry_points={"console_scripts": ["replace=mass_replace.__main__:main"]},
    install_requires=REQUIRED,
    include_package_data=True,
    license="MIT",
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: Implementation :: CPython",
        "Development Status :: 2 - Pre-Alpha",
    ],
    # $ setup.py publish support.
    cmdclass={"upload": UploadCommand},
)

==> mass_replace-0.0.3.tar.gz: mass_replace-0.0.3/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import pathlib
from setuptools import find_packages, setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

import os
import sys
import pathlib
from shutil import rmtree

from setuptools import find_packages, setup, Command

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# Package meta-data.
NAME = "mass_replace"
DESCRIPTION = "Walkthrough directories and find and replace txt on select filetypes."
URL = "https://github.com/Kilo59/mass_replace"
EMAIL = "gabriel59kg@gmail.com"
AUTHOR = "Gabriel Gore"
REQUIRES_PYTHON = ">=3.5.0"
# replace with __version__
VERSION = "0.0.3"

# What packages are required for this module to be executed?
REQUIRED = ["pyaml"]

# Import the README and use it as the long-description.
# The text of the README file
README = (HERE / "README.md").read_text(encoding="utf-8")

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    with open(HERE.joinpath(NAME, "__version__.py")) as f:
        exec(f.read(), about)
else:
    about["__version__"] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = "Build and publish the package."
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print("\033[1m{0}\033[0m".format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status("Removing previous builds…")
            rmtree(HERE.joinpath("dist"))
        except OSError:
            pass

        self.status("Building Source and Wheel (universal) distribution…")
        os.system("{0} setup.py sdist bdist_wheel --universal".format(sys.executable))

        self.status("Uploading the package to PyPi via Twine…")
        os.system("twine upload dist/*")

        self.status("Pushing git tags…")
        os.system("git tag v{0}".format(about["__version__"]))
        os.system("git push --tags")

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about["__version__"],
    description=DESCRIPTION,
    long_description=README,
    long_description_content_type="text/markdown",
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(exclude=("tests",)),
    entry_points={"console_scripts": ["replace=mass_replace.__main__:main"]},
    install_requires=REQUIRED,
    include_package_data=True,
    license="MIT",
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: Implementation :: CPython",
        "Development Status :: 2 - Pre-Alpha",
    ],
    # $ setup.py publish support.
    cmdclass={"upload": UploadCommand},
)
